from django.core.management import call_command
from django.test import TestCase
from django.utils.six import StringIO


class CommandsTest(TestCase):

    def test_creatersakey_output(self):
        out = StringIO()
        call_command('creatersakey', stdout=out)
        self.assertIn('RSA key successfully created', out.getvalue())

    def test_makemigrations_output(self):
        out = StringIO()
        call_command('makemigrations', 'oidc_provider', stdout=out)
        self.assertIn('No changes detected in app', out.getvalue())



from django.test import TestCase
from oidc_provider.lib.claims import ScopeClaims
from oidc_provider.tests.app.utils import create_fake_user


class ClaimsTestCase(TestCase):

    def setUp(self):
        self.user = create_fake_user()
        self.scopes = ['openid', 'address', 'email', 'phone', 'profile']
        self.scopeClaims = ScopeClaims(self.user, self.scopes)

    def test_clean_dic(self):
        """ assert that _clean_dic function returns a clean dictionnary
            (no empty claims) """
        dict_to_clean = {
            'phone_number_verified': '',
            'middle_name': '',
            'name': 'John Doe',
            'website': '',
            'profile': '',
            'family_name': 'Doe',
            'birthdate': '',
            'preferred_username': '',
            'picture': '',
            'zoneinfo': '',
            'locale': '',
            'gender': '',
            'updated_at': '',
            'address': {},
            'given_name': 'John',
            'email_verified': '',
            'nickname': '',
            'email': u'johndoe@example.com',
            'phone_number': '',
        }
        clean_dict = self.scopeClaims._clean_dic(dict_to_clean)
        self.assertEquals(
            clean_dict,
            {
                'family_name': 'Doe',
                'given_name': 'John',
                'name': 'John Doe',
                'email': u'johndoe@example.com'
            }
        )



from django.conf.urls import url
from django.views.decorators.csrf import csrf_exempt
from oidc_provider import views


urlpatterns = [
    url(r'^authorize/?$', views.AuthorizeView.as_view(), name='authorize'),
    url(r'^token/?$', csrf_exempt(views.TokenView.as_view()), name='token'),
    url(r'^userinfo/?$', csrf_exempt(views.userinfo), name='userinfo'),
    url(r'^logout/?$', views.LogoutView.as_view(), name='logout'),

    url(r'^\.well-known/openid-configuration/?$', views.ProviderInfoView.as_view(), name='provider_info'),
    url(r'^jwks/?$', views.JwksView.as_view(), name='jwks'),
]
